==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/operation/SubmitFormActionType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SubmitFormActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SubmitFormActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType"&gt;
 *       &lt;choice maxOccurs="unbounded"&gt;
 *         &lt;element name="field" type="{http://schema.webpdf.de/1.0/operation}FormFieldSelectionType"/&gt;
 *       &lt;/choice&gt;
 *       &lt;attribute name="url" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="exclude" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="includeNoValueFields" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="exportFormat" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="getMethod" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="submitCoordinates" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="xfdf" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="includeAppendSaves" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="includeAnnotations" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="submitPDF" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="canonicalFormat" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="excludeNonUserAnnotations" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="excludeFDFSourceOrTargetFile" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="embedForm" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SubmitFormActionType", propOrder = {
    "field"
})
public class SubmitFormActionType
    extends ActionEventType
{

    protected List<FormFieldSelectionType> field;
    @XmlAttribute(name = "url")
    protected String url;
    @XmlAttribute(name = "exclude")
    protected Boolean exclude;
    @XmlAttribute(name = "includeNoValueFields")
    protected Boolean includeNoValueFields;
    @XmlAttribute(name = "exportFormat")
    protected Boolean exportFormat;
    @XmlAttribute(name = "getMethod")
    protected Boolean getMethod;
    @XmlAttribute(name = "submitCoordinates")
    protected Boolean submitCoordinates;
    @XmlAttribute(name = "xfdf")
    protected Boolean xfdf;
    @XmlAttribute(name = "includeAppendSaves")
    protected Boolean includeAppendSaves;
    @XmlAttribute(name = "includeAnnotations")
    protected Boolean includeAnnotations;
    @XmlAttribute(name = "submitPDF")
    protected Boolean submitPDF;
    @XmlAttribute(name = "canonicalFormat")
    protected Boolean canonicalFormat;
    @XmlAttribute(name = "excludeNonUserAnnotations")
    protected Boolean excludeNonUserAnnotations;
    @XmlAttribute(name = "excludeFDFSourceOrTargetFile")
    protected Boolean excludeFDFSourceOrTargetFile;
    @XmlAttribute(name = "embedForm")
    protected Boolean embedForm;

    /**
     * Gets the value of the field property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the field property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getField().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FormFieldSelectionType }
     * 
     * 
     */
    public List<FormFieldSelectionType> getField() {
        if (field == null) {
            field = new ArrayList<FormFieldSelectionType>();
        }
        return this.field;
    }

    public boolean isSetField() {
        return ((this.field!= null)&&(!this.field.isEmpty()));
    }

    public void unsetField() {
        this.field = null;
    }

    /**
     * Gets the value of the url property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUrl() {
        if (url == null) {
            return "";
        } else {
            return url;
        }
    }

    /**
     * Sets the value of the url property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUrl(String value) {
        this.url = value;
    }

    public boolean isSetUrl() {
        return (this.url!= null);
    }

    /**
     * Gets the value of the exclude property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExclude() {
        if (exclude == null) {
            return false;
        } else {
            return exclude;
        }
    }

    /**
     * Sets the value of the exclude property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExclude(boolean value) {
        this.exclude = value;
    }

    public boolean isSetExclude() {
        return (this.exclude!= null);
    }

    public void unsetExclude() {
        this.exclude = null;
    }

    /**
     * Gets the value of the includeNoValueFields property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeNoValueFields() {
        if (includeNoValueFields == null) {
            return false;
        } else {
            return includeNoValueFields;
        }
    }

    /**
     * Sets the value of the includeNoValueFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeNoValueFields(boolean value) {
        this.includeNoValueFields = value;
    }

    public boolean isSetIncludeNoValueFields() {
        return (this.includeNoValueFields!= null);
    }

    public void unsetIncludeNoValueFields() {
        this.includeNoValueFields = null;
    }

    /**
     * Gets the value of the exportFormat property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExportFormat() {
        if (exportFormat == null) {
            return false;
        } else {
            return exportFormat;
        }
    }

    /**
     * Sets the value of the exportFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExportFormat(boolean value) {
        this.exportFormat = value;
    }

    public boolean isSetExportFormat() {
        return (this.exportFormat!= null);
    }

    public void unsetExportFormat() {
        this.exportFormat = null;
    }

    /**
     * Gets the value of the getMethod property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isGetMethod() {
        if (getMethod == null) {
            return false;
        } else {
            return getMethod;
        }
    }

    /**
     * Sets the value of the getMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setGetMethod(boolean value) {
        this.getMethod = value;
    }

    public boolean isSetGetMethod() {
        return (this.getMethod!= null);
    }

    public void unsetGetMethod() {
        this.getMethod = null;
    }

    /**
     * Gets the value of the submitCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isSubmitCoordinates() {
        if (submitCoordinates == null) {
            return false;
        } else {
            return submitCoordinates;
        }
    }

    /**
     * Sets the value of the submitCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSubmitCoordinates(boolean value) {
        this.submitCoordinates = value;
    }

    public boolean isSetSubmitCoordinates() {
        return (this.submitCoordinates!= null);
    }

    public void unsetSubmitCoordinates() {
        this.submitCoordinates = null;
    }

    /**
     * Gets the value of the xfdf property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isXfdf() {
        if (xfdf == null) {
            return false;
        } else {
            return xfdf;
        }
    }

    /**
     * Sets the value of the xfdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setXfdf(boolean value) {
        this.xfdf = value;
    }

    public boolean isSetXfdf() {
        return (this.xfdf!= null);
    }

    public void unsetXfdf() {
        this.xfdf = null;
    }

    /**
     * Gets the value of the includeAppendSaves property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeAppendSaves() {
        if (includeAppendSaves == null) {
            return false;
        } else {
            return includeAppendSaves;
        }
    }

    /**
     * Sets the value of the includeAppendSaves property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeAppendSaves(boolean value) {
        this.includeAppendSaves = value;
    }

    public boolean isSetIncludeAppendSaves() {
        return (this.includeAppendSaves!= null);
    }

    public void unsetIncludeAppendSaves() {
        this.includeAppendSaves = null;
    }

    /**
     * Gets the value of the includeAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeAnnotations() {
        if (includeAnnotations == null) {
            return false;
        } else {
            return includeAnnotations;
        }
    }

    /**
     * Sets the value of the includeAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeAnnotations(boolean value) {
        this.includeAnnotations = value;
    }

    public boolean isSetIncludeAnnotations() {
        return (this.includeAnnotations!= null);
    }

    public void unsetIncludeAnnotations() {
        this.includeAnnotations = null;
    }

    /**
     * Gets the value of the submitPDF property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isSubmitPDF() {
        if (submitPDF == null) {
            return false;
        } else {
            return submitPDF;
        }
    }

    /**
     * Sets the value of the submitPDF property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSubmitPDF(boolean value) {
        this.submitPDF = value;
    }

    public boolean isSetSubmitPDF() {
        return (this.submitPDF!= null);
    }

    public void unsetSubmitPDF() {
        this.submitPDF = null;
    }

    /**
     * Gets the value of the canonicalFormat property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanonicalFormat() {
        if (canonicalFormat == null) {
            return false;
        } else {
            return canonicalFormat;
        }
    }

    /**
     * Sets the value of the canonicalFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanonicalFormat(boolean value) {
        this.canonicalFormat = value;
    }

    public boolean isSetCanonicalFormat() {
        return (this.canonicalFormat!= null);
    }

    public void unsetCanonicalFormat() {
        this.canonicalFormat = null;
    }

    /**
     * Gets the value of the excludeNonUserAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExcludeNonUserAnnotations() {
        if (excludeNonUserAnnotations == null) {
            return false;
        } else {
            return excludeNonUserAnnotations;
        }
    }

    /**
     * Sets the value of the excludeNonUserAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExcludeNonUserAnnotations(boolean value) {
        this.excludeNonUserAnnotations = value;
    }

    public boolean isSetExcludeNonUserAnnotations() {
        return (this.excludeNonUserAnnotations!= null);
    }

    public void unsetExcludeNonUserAnnotations() {
        this.excludeNonUserAnnotations = null;
    }

    /**
     * Gets the value of the excludeFDFSourceOrTargetFile property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExcludeFDFSourceOrTargetFile() {
        if (excludeFDFSourceOrTargetFile == null) {
            return false;
        } else {
            return excludeFDFSourceOrTargetFile;
        }
    }

    /**
     * Sets the value of the excludeFDFSourceOrTargetFile property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExcludeFDFSourceOrTargetFile(boolean value) {
        this.excludeFDFSourceOrTargetFile = value;
    }

    public boolean isSetExcludeFDFSourceOrTargetFile() {
        return (this.excludeFDFSourceOrTargetFile!= null);
    }

    public void unsetExcludeFDFSourceOrTargetFile() {
        this.excludeFDFSourceOrTargetFile = null;
    }

    /**
     * Gets the value of the embedForm property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isEmbedForm() {
        if (embedForm == null) {
            return false;
        } else {
            return embedForm;
        }
    }

    /**
     * Sets the value of the embedForm property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEmbedForm(boolean value) {
        this.embedForm = value;
    }

    public boolean isSetEmbedForm() {
        return (this.embedForm!= null);
    }

    public void unsetEmbedForm() {
        this.embedForm = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SubmitFormActionType.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;When activated, the submitForm action will send the names and values of all selected form fields to the specified URL (Uniform Resource Locator). You can use the "field" element as many times as necessary.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SubmitFormActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SubmitFormActionType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType">
 *       <choice maxOccurs="unbounded">
 *         <element name="field" type="{http://schema.webpdf.de/1.0/operation}FormFieldSelectionType"/>
 *       </choice>
 *       <attribute name="url" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="exclude" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="includeNoValueFields" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="exportFormat" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="getMethod" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="submitCoordinates" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="xfdf" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="includeAppendSaves" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="includeAnnotations" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="submitPDF" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="canonicalFormat" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="excludeNonUserAnnotations" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="excludeFDFSourceOrTargetFile" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="embedForm" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SubmitFormActionType", propOrder = {
    "field"
})
public class SubmitFormActionType
    extends ActionEventType
{

    protected List<FormFieldSelectionType> field;
    @XmlAttribute(name = "url")
    protected String url;
    @XmlAttribute(name = "exclude")
    protected Boolean exclude;
    @XmlAttribute(name = "includeNoValueFields")
    protected Boolean includeNoValueFields;
    @XmlAttribute(name = "exportFormat")
    protected Boolean exportFormat;
    @XmlAttribute(name = "getMethod")
    protected Boolean getMethod;
    @XmlAttribute(name = "submitCoordinates")
    protected Boolean submitCoordinates;
    @XmlAttribute(name = "xfdf")
    protected Boolean xfdf;
    @XmlAttribute(name = "includeAppendSaves")
    protected Boolean includeAppendSaves;
    @XmlAttribute(name = "includeAnnotations")
    protected Boolean includeAnnotations;
    @XmlAttribute(name = "submitPDF")
    protected Boolean submitPDF;
    @XmlAttribute(name = "canonicalFormat")
    protected Boolean canonicalFormat;
    @XmlAttribute(name = "excludeNonUserAnnotations")
    protected Boolean excludeNonUserAnnotations;
    @XmlAttribute(name = "excludeFDFSourceOrTargetFile")
    protected Boolean excludeFDFSourceOrTargetFile;
    @XmlAttribute(name = "embedForm")
    protected Boolean embedForm;

    /**
     * Gets the value of the field property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the field property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getField().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FormFieldSelectionType }
     * 
     * 
     * @return
     *     The value of the field property.
     */
    public List<FormFieldSelectionType> getField() {
        if (field == null) {
            field = new ArrayList<>();
        }
        return this.field;
    }

    public boolean isSetField() {
        return ((this.field!= null)&&(!this.field.isEmpty()));
    }

    public void unsetField() {
        this.field = null;
    }

    /**
     * Gets the value of the url property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUrl() {
        if (url == null) {
            return "";
        } else {
            return url;
        }
    }

    /**
     * Sets the value of the url property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUrl(String value) {
        this.url = value;
    }

    public boolean isSetUrl() {
        return (this.url!= null);
    }

    /**
     * Gets the value of the exclude property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExclude() {
        if (exclude == null) {
            return false;
        } else {
            return exclude;
        }
    }

    /**
     * Sets the value of the exclude property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExclude(boolean value) {
        this.exclude = value;
    }

    public boolean isSetExclude() {
        return (this.exclude!= null);
    }

    public void unsetExclude() {
        this.exclude = null;
    }

    /**
     * Gets the value of the includeNoValueFields property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeNoValueFields() {
        if (includeNoValueFields == null) {
            return false;
        } else {
            return includeNoValueFields;
        }
    }

    /**
     * Sets the value of the includeNoValueFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeNoValueFields(boolean value) {
        this.includeNoValueFields = value;
    }

    public boolean isSetIncludeNoValueFields() {
        return (this.includeNoValueFields!= null);
    }

    public void unsetIncludeNoValueFields() {
        this.includeNoValueFields = null;
    }

    /**
     * Gets the value of the exportFormat property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExportFormat() {
        if (exportFormat == null) {
            return false;
        } else {
            return exportFormat;
        }
    }

    /**
     * Sets the value of the exportFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExportFormat(boolean value) {
        this.exportFormat = value;
    }

    public boolean isSetExportFormat() {
        return (this.exportFormat!= null);
    }

    public void unsetExportFormat() {
        this.exportFormat = null;
    }

    /**
     * Gets the value of the getMethod property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isGetMethod() {
        if (getMethod == null) {
            return false;
        } else {
            return getMethod;
        }
    }

    /**
     * Sets the value of the getMethod property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setGetMethod(boolean value) {
        this.getMethod = value;
    }

    public boolean isSetGetMethod() {
        return (this.getMethod!= null);
    }

    public void unsetGetMethod() {
        this.getMethod = null;
    }

    /**
     * Gets the value of the submitCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isSubmitCoordinates() {
        if (submitCoordinates == null) {
            return false;
        } else {
            return submitCoordinates;
        }
    }

    /**
     * Sets the value of the submitCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSubmitCoordinates(boolean value) {
        this.submitCoordinates = value;
    }

    public boolean isSetSubmitCoordinates() {
        return (this.submitCoordinates!= null);
    }

    public void unsetSubmitCoordinates() {
        this.submitCoordinates = null;
    }

    /**
     * Gets the value of the xfdf property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isXfdf() {
        if (xfdf == null) {
            return false;
        } else {
            return xfdf;
        }
    }

    /**
     * Sets the value of the xfdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setXfdf(boolean value) {
        this.xfdf = value;
    }

    public boolean isSetXfdf() {
        return (this.xfdf!= null);
    }

    public void unsetXfdf() {
        this.xfdf = null;
    }

    /**
     * Gets the value of the includeAppendSaves property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeAppendSaves() {
        if (includeAppendSaves == null) {
            return false;
        } else {
            return includeAppendSaves;
        }
    }

    /**
     * Sets the value of the includeAppendSaves property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeAppendSaves(boolean value) {
        this.includeAppendSaves = value;
    }

    public boolean isSetIncludeAppendSaves() {
        return (this.includeAppendSaves!= null);
    }

    public void unsetIncludeAppendSaves() {
        this.includeAppendSaves = null;
    }

    /**
     * Gets the value of the includeAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIncludeAnnotations() {
        if (includeAnnotations == null) {
            return false;
        } else {
            return includeAnnotations;
        }
    }

    /**
     * Sets the value of the includeAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeAnnotations(boolean value) {
        this.includeAnnotations = value;
    }

    public boolean isSetIncludeAnnotations() {
        return (this.includeAnnotations!= null);
    }

    public void unsetIncludeAnnotations() {
        this.includeAnnotations = null;
    }

    /**
     * Gets the value of the submitPDF property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isSubmitPDF() {
        if (submitPDF == null) {
            return false;
        } else {
            return submitPDF;
        }
    }

    /**
     * Sets the value of the submitPDF property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSubmitPDF(boolean value) {
        this.submitPDF = value;
    }

    public boolean isSetSubmitPDF() {
        return (this.submitPDF!= null);
    }

    public void unsetSubmitPDF() {
        this.submitPDF = null;
    }

    /**
     * Gets the value of the canonicalFormat property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCanonicalFormat() {
        if (canonicalFormat == null) {
            return false;
        } else {
            return canonicalFormat;
        }
    }

    /**
     * Sets the value of the canonicalFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCanonicalFormat(boolean value) {
        this.canonicalFormat = value;
    }

    public boolean isSetCanonicalFormat() {
        return (this.canonicalFormat!= null);
    }

    public void unsetCanonicalFormat() {
        this.canonicalFormat = null;
    }

    /**
     * Gets the value of the excludeNonUserAnnotations property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExcludeNonUserAnnotations() {
        if (excludeNonUserAnnotations == null) {
            return false;
        } else {
            return excludeNonUserAnnotations;
        }
    }

    /**
     * Sets the value of the excludeNonUserAnnotations property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExcludeNonUserAnnotations(boolean value) {
        this.excludeNonUserAnnotations = value;
    }

    public boolean isSetExcludeNonUserAnnotations() {
        return (this.excludeNonUserAnnotations!= null);
    }

    public void unsetExcludeNonUserAnnotations() {
        this.excludeNonUserAnnotations = null;
    }

    /**
     * Gets the value of the excludeFDFSourceOrTargetFile property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExcludeFDFSourceOrTargetFile() {
        if (excludeFDFSourceOrTargetFile == null) {
            return false;
        } else {
            return excludeFDFSourceOrTargetFile;
        }
    }

    /**
     * Sets the value of the excludeFDFSourceOrTargetFile property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExcludeFDFSourceOrTargetFile(boolean value) {
        this.excludeFDFSourceOrTargetFile = value;
    }

    public boolean isSetExcludeFDFSourceOrTargetFile() {
        return (this.excludeFDFSourceOrTargetFile!= null);
    }

    public void unsetExcludeFDFSourceOrTargetFile() {
        this.excludeFDFSourceOrTargetFile = null;
    }

    /**
     * Gets the value of the embedForm property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isEmbedForm() {
        if (embedForm == null) {
            return false;
        } else {
            return embedForm;
        }
    }

    /**
     * Sets the value of the embedForm property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEmbedForm(boolean value) {
        this.embedForm = value;
    }

    public boolean isSetEmbedForm() {
        return (this.embedForm!= null);
    }

    public void unsetEmbedForm() {
        this.embedForm = null;
    }

}
